local _G = _G
local Cartographer3 = _G.Cartographer3
local Cartographer3_Data = Cartographer3.Data

local L = Cartographer3.L

local LibGuildPositions = LibStub("LibGuildPositions-1.0", true)
if not LibGuildPositions then
	-- TODO: put a message or something?
	return
end

local guildPOIs = {}

local guildieNameToClass = setmetatable({}, {__index=function(self, name)
	for i = 1, GetNumGuildMembers() do
		local n, _, _, _, _, _, _, _, _, _, class = GetGuildRosterInfo(i)
		if n == name then
			self[name] = class
			return class
		end
	end
	self[name] = "UNKNOWN"
	return "UNKNOWN"
end})

local function guildMemberPOI_AddDataToFullTooltip(self)
	local name = self.name
	WorldMapTooltip:AddDoubleLine(L["Guild:"], name)
	
	-- TODO: add more info
end
local function guildMemberPOI_AddDataToTooltipLine(self)
	local name = self.name
	WorldMapTooltip:AddDoubleLine(L["Guild:"], name)
	
	-- TODO: add more info
end

local guildMemberNum = 0
function Cartographer3:ShowGuildMember(event, name, x, y, zone)
	local gx, gy = Cartographer3.Utils.ConvertZoneCoordinateToUniverseCoordinate(zone, x, y)
	if gx then
		local poi = guildPOIs[name]
		if not poi then
			poi = table.remove(guildPOIs)
			if not poi then
				guildMemberNum = guildMemberNum + 1
				poi = CreateFrame("Frame", Cartographer3_Data.mapView:GetName() .. "_GuildMember" .. guildMemberNum, Cartographer3_Data.mapView)
				poi.AddDataToFullTooltip = guildMemberPOI_AddDataToFullTooltip
				poi.AddDataToTooltipLine = guildMemberPOI_AddDataToTooltipLine
				poi:SetWidth(1)
				poi:SetHeight(1)
				Cartographer3.AddPOI(poi)
				local outer = poi:CreateTexture(nil--[[poi:GetName() .. "_OuterTexture"]], "BORDER")
				poi.outer = outer
				outer:SetAllPoints()
				outer:SetTexture([[Interface\AddOns\Cartographer3\Artwork\GuildOuter]])
				local inner = poi:CreateTexture(nil--[[poi:GetName() .. "_InnerTexture"]], "ARTWORK")
				poi.inner = inner
				inner:SetAllPoints()
				inner:SetTexture([[Interface\AddOns\Cartographer3\Artwork\GuildInner]])
			end
			guildPOIs[name] = poi
			poi.name = name
			
			local class = guildieNameToClass[name]
			local classColor = RAID_CLASS_COLORS[class]
			if classColor then
				poi.inner:SetVertexColor(classColor.r, classColor.g, classColor.b)
			else
				poi.inner:SetVertexColor(0.8, 0.8, 0.8)
			end
		end
	
		poi:SetPoint("CENTER", gx, gy)
		poi:Show()
	else
		local poi = guildPOIs[name]
		if poi then
			guildPOIs[name] = nil
			guildPOIs[#guildPOIs] = poi
			poi.name = nil
			poi:Hide()
		end
	end
end

LibGuildPositions.RegisterCallback(Cartographer3, "Position", "ShowGuildMember")
LibGuildPositions.RegisterCallback(Cartographer3, "Clear", "ShowGuildMember")
